# History

## 0.1.8 (2019-05-05)

* :issue:`8` Include capability to optimize alpha parameter

## 0.1.7 (2019-04-26)

* Complete code coverage of existing capabilities.

## 0.1.6 (2019-04-24)

* :issue:`6` Include Jupyter Notebook in Examples

## 0.1.5 (2019-04-24)

* :issue:`5` Create an Example Gallery in the Documentation

## 0.1.4 (2019-04-24)

* Bug fixes.

## 0.1.3 (2019-04-24)

* Bug fixes.

## 0.1.2 (2019-04-24)

* Bug fixes.

## 0.1.1 (2019-04-24)

* Bug fixes.

## 0.1.0 (2019-04-23)

* First release on PyPI.
